#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hakyll
version:              4.16.5.0
visibility:           public
id:                   hakyll-4.16.5.0-5P3UH1f16YI2DGXA1SDZKY
key:                  hakyll-4.16.5.0-5P3UH1f16YI2DGXA1SDZKY
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             http://jaspervdj.be/hakyll
synopsis:             A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:

    * <http://jaspervdj.be/hakyll>

    If you seek assistance, there'\''s:

    * A google group: <http://groups.google.com/group/hakyll>

    * An IRC channel, @#hakyll@ on irc.libera.chat (we *do not* have a channel on Freenode anymore)

    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.

category:             Web
abi:                  e13d21386743fdc2c2a65a8f08c286c0
exposed:              True
exposed-modules:
    Hakyll Hakyll.Commands Hakyll.Core.Compiler
    Hakyll.Core.Compiler.Internal Hakyll.Core.Configuration
    Hakyll.Core.Dependencies Hakyll.Core.File Hakyll.Core.Identifier
    Hakyll.Core.Identifier.Pattern Hakyll.Core.Item Hakyll.Core.Logger
    Hakyll.Core.Metadata Hakyll.Core.Provider
    Hakyll.Core.Provider.Metadata Hakyll.Core.Routes Hakyll.Core.Rules
    Hakyll.Core.Rules.Internal Hakyll.Core.Runtime Hakyll.Core.Store
    Hakyll.Core.UnixFilter Hakyll.Core.Util.File
    Hakyll.Core.Util.String Hakyll.Core.Writable Hakyll.Main
    Hakyll.Web.CompressCss Hakyll.Web.Feed Hakyll.Web.Html
    Hakyll.Web.Html.RelativizeUrls Hakyll.Web.Meta.JSONLD
    Hakyll.Web.Meta.OpenGraph Hakyll.Web.Meta.TwitterCard
    Hakyll.Web.Paginate Hakyll.Web.Pandoc Hakyll.Web.Pandoc.Biblio
    Hakyll.Web.Pandoc.FileType Hakyll.Web.Redirect Hakyll.Web.Tags
    Hakyll.Web.Template Hakyll.Web.Template.Context
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Internal.Element
    Hakyll.Web.Template.Internal.Trim Hakyll.Web.Template.List

hidden-modules:
    Data.List.Extended Data.Yaml.Extended Hakyll.Check
    Hakyll.Core.Compiler.Require
    Hakyll.Core.Identifier.Pattern.Internal Hakyll.Core.Item.SomeItem
    Hakyll.Core.Provider.Internal Hakyll.Core.Provider.MetadataCache
    Hakyll.Core.Util.Parser Paths_hakyll Hakyll.Preview.Poll
    Hakyll.Preview.Server Hakyll.Web.Pandoc.Binary

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hakyll-4.16.5.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hakyll-4.16.5.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hakyll-4.16.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hakyll
hs-libraries:         HShakyll-4.16.5.0-5P3UH1f16YI2DGXA1SDZKY
depends:
    aeson-2.2.2.0-p30NU7EGMRKoAj5LcAXNN base-4.18.2.1 binary-0.8.9.1
    blaze-html-0.9.2.0-IQpYWAMPsDd8u1EAzkbal7 bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG
    deepseq-1.4.8.1 directory-1.3.8.5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    fsnotify-0.4.4.0-IARpfp43Asf7grHlVfC6Ku
    hashable-1.4.7.0-8JCT2FqI0OIc7eryHiY9E
    http-conduit-2.3.9.1-4GHCqDaBuCM58aeeW5fqr2
    http-types-0.12.4-D4ln0jiwEOhAKcR3fqSchY
    lrucache-1.2.0.1-34e4rU2OpGtGXjnvLtyFkI mtl-2.3.1
    network-uri-2.6.4.2-HyBVnFdXLs0Dgiq4qkHmFH
    optparse-applicative-0.18.1.0-2OPlFtvlr5yI8qFRB5F8bn
    pandoc-3.6.1-F7peNFGbigo1UIAggdl1Pr
    pandoc-types-1.23.1.1-KNM8u0wir7d1sJ8wTKLYRL parsec-3.1.16.1
    process-1.6.19.0 random-1.2.1.3-L4ByjUo9HMh9NaA0HunG5L
    regex-tdfa-1.3.2.5-5Xsa8Nkm5ozG5wMRmCPABC
    resourcet-1.3.0-1zDmXgfXfhGHcZ53EkSGgY
    scientific-0.3.8.1-8GGUGhnyv3iL0QkuRDa0Ak
    tagsoup-0.14.8-BmBdL3Esmw8Ks8pI1RIqPE template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-8XUEctZKps57K6Zw5siYoh
    vector-0.13.2.0-pkGAkHyCfVA94J1hIBHJi
    wai-3.2.4-HOJRNxSLXyTJ5Lq7jmcw5j
    wai-app-static-3.1.9.1-35v1AtXcX9pKyf39jb52iZ
    warp-3.4.0-7sSgt5pHh8JChjZVo9TeMR
    yaml-0.11.11.2-Au2qdn6SLCA15BHMrAh7pn

haddock-interfaces:   /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html:         /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

